@@ -13,7 +13,8 @@ class MainHandler(tornado.web.RequestHandler):
         cls.config = config
 
     def get(self):
-        if self.request.arguments['wsdl']:
+        if self.request.get_arguments('wsdl'):
+            self.set_header( 'Content-Type', 'text/xml' )
             with open('./wsdl.xml') as f:
                 return self.write(f.read())
         self.write(json.dumps(MainHandler.config, indent=4))
